#
# Conditional build:
%bcond_without	apidocs		# API documentation
%bcond_without	static_libs	# static library
%bcond_with	gnutls		# GnuTLS instead of OpenSSL for SSL
%bcond_without	kerberos5	# Kerberos V support
%bcond_without	libproxy	# libproxy support
%bcond_without	pakchois	# pakchois-based PKCS#11 support

Summary:	An HTTP and WebDAV client library
Summary(pl.UTF-8):	Biblioteka kliencka HTTP i WebDAV
Name:		neon
Version:	0.32.5
Release:	1
License:	LGPL v2+
Group:		Libraries
Source0:	https://notroj.github.io/neon/%{name}-%{version}.tar.gz
# Source0-md5:	7976b1cd67b7228cddb7eb4f39640ac5
URL:		https://notroj.github.io/neon/
BuildRequires:	autoconf >= 2.58
BuildRequires:	automake
%{?with_gnutls:BuildRequires:	gnutls-devel >= 3}
%{?with_kerberos5:BuildRequires:	heimdal-devel}
%{?with_libproxy:BuildRequires:	libproxy-devel}
BuildRequires:	libtool
BuildRequires:	libxml2-devel
%{!?with_gnutls:BuildRequires:	openssl-devel >= 0.9.7d}
%{?with_pakchois:BuildRequires:	pakchois-devel}
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.752
BuildRequires:	zlib-devel
%if %{without gnutls}
%requires_ge_to	openssl openssl-devel
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
neon is an HTTP and WebDAV client library, with a C interface.
Featuring:
 - High-level interface to HTTP and WebDAV methods (PUT, GET, HEAD
   etc).
 - Low-level interface to HTTP request handling, to allow implementing
   new methods easily.
 - HTTP/1.1 and HTTP/1.0 persistent connections.
 - RFC2617 basic and digest authentication (including auth-int,
   md5-sess).
 - Proxy support (including basic/digest authentication).
 - Generic WebDAV 207 XML response handling mechanism.
 - XML parsing using the expat or libxml parsers.
 - Easy generation of error messages from 207 error responses.
 - WebDAV resource manipulation: MOVE, COPY, DELETE, MKCOL.
 - WebDAV metadata support: set and remove properties, query any set of
   properties (PROPPATCH/PROPFIND).

%description -l pl.UTF-8
neon to biblioteka kliencka HTTP i WebDAV z interfejsem w C.
Możliwości:
 - wysokopoziomowy interfejs do metod HTTP i WebDAV (PUT, GET,
   HEAD...),
 - niskopoziomowy interfejs do obsługi żądań HTTP pozwalający łatwo
   implementować nowe metody,
 - stałe połączenia HTTP/1.1 i HTTP/1.0,
 - uwierzytelnianie podstawowe (basic) i skrótem RFC-2617 (auth-int,
   md5-sess...),
 - obsługa proxy (w tym uwierzytelnianie podstawowe i skrótem),
 - mechanizm obsługi odpowiedzi WebDAV 207 XML,
 - analiza składniowa XML przy pomocy expat lub libxml,
 - proste generowanie komunikatów błędów dla odpowiedzi 207,
 - manipulowanie zasobami WebDAV: MOVE, COPY, DELETE, MKCOL,
 - obsługa metadanych WebDAV: ustawianie i usuwanie atrybutów,
   sprawdzanie dowolnego zbioru atrybutów (PROPPATCH/PROPFIND).

%package devel
Summary:	Header files for neon
Summary(pl.UTF-8):	Pliki nagłówkowe neon
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
%{?with_gnutls:Requires:	gnutls-devel >= 3}
%{?with_kerberos5:Requires: heimdal-devel}
%{?with_libproxy:Requires: libproxy-devel}
Requires:	libxml2-devel
%{!?with_gnutls:Requires:	openssl-devel >= 0.9.7c}
%{?with_pakchois:Requires: pakchois-devel}

%description devel
C header files for the neon library.

%description devel -l pl.UTF-8
Pliki nagłówkowe dla biblioteki neon.

%package static
Summary:	Static libraries for neon
Summary(pl.UTF-8):	Biblioteki statyczne neon
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static neon libraries.

%description static -l pl.UTF-8
Statyczne biblioteki neon.

%package apidocs
Summary:	neon API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki neon
Group:		Documentation
BuildArch:	noarch

%description apidocs
API and internal documentation for neon library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki neon.

%prep
%setup -q

%build
%{__libtoolize}
%{__aclocal} -I macros
%{__autoconf}
%configure \
	--enable-threadsafe-ssl=posix \
	--enable-shared \
	%{!?with_static_libs:--disable-static} \
	--with-ca-bundle=/etc/certs/ca-certificates.crt \
	%{!?with_kerberos5:--without-gssapi} \
	%{!?with_libproxy:--without-libproxy} \
	--with-libxml2 \
	--with-pakchois%{!?with_pakchois:=no} \
	--with-ssl=%{?with_gnutls:gnutls}%{!?with_gnutls:openssl}

%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/html
%{__rm} $RPM_BUILD_ROOT%{_libdir}/*.la

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS BUGS ChangeLog NEWS README.md THANKS TODO
%attr(755,root,root) %{_libdir}/libneon.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libneon.so.27

%files devel
%defattr(644,root,root,755)
%doc doc/*.txt
%attr(755,root,root) %{_bindir}/neon-config
%attr(755,root,root) %{_libdir}/libneon.so
%{_includedir}/neon
%{_pkgconfigdir}/neon.pc
%{_mandir}/man1/neon-config.1*
%{_mandir}/man3/ne_*.3*
%{_mandir}/man3/neon.3*

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libneon.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%doc doc/html/*
%endif
%changelog
* Mon Apr 03 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/neon.git;a=log;h=master

* Mon Apr 03 2023 Jakub Bogusz <qboosh@pld-linux.org> d5d1493
- updated to 0.32.5

* Sat Apr 02 2022 Jakub Bogusz <qboosh@pld-linux.org> d0b5792
- updated to 0.32.2

* Fri Sep 24 2021 Jan Rękorajski <baggins@pld-linux.org> 6cd5edf
- rebuild with openssl 3.0.0

* Sun Mar 07 2021 Jan Rękorajski <baggins@pld-linux.org> 4d871f4
- unconditional noarch subpackages

* Sun Dec 13 2020 Jakub Bogusz <qboosh@pld-linux.org> ef4158e
- new URLs, updated to 0.31.2

* Sun Mar 29 2020 Jakub Bogusz <qboosh@pld-linux.org> 06c4e5c
- updated to 0.31.0
- removed obsolete openssl patch

* Mon Apr 22 2019 Jakub Bogusz <qboosh@pld-linux.org> 6d88827
- added gnutls bcond

* Fri Jan 18 2019 Marcin Krol <hawk@tld-linux.org> e1593dd
- release 2

* Tue Sep 18 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> ef26a73
- up to 0.30.2

* Sat Sep 15 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 8a28268
- release 8 (by relup.sh)

* Sat Mar 05 2016 Elan Ruusamäe <glen@delfi.ee> 77116a7
- openssl 1.0.2g rebuild
- release 7 (by relup.sh)

* Fri Sep 04 2015 Elan Ruusamäe <glen@delfi.ee> 486a68f
- builds with old libtool as well

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> a2506a3
- x32 rebuild
- release 6 (by relup.sh)

* Sat Jan 10 2015 Elan Ruusamäe <glen@delfi.ee> c6681b4
- drop openssl-version-check.patch, no longer needed to patch (such code not present)

* Sat Jan 10 2015 Elan Ruusamäe <glen@delfi.ee> 547f737
- remove compile time ssl version check. relax openssl version strictness. refs 00c6dbc, 8c7138b5

* Fri Jan 09 2015 Łukasz Kieś <kiesiu@pld-linux.org> ec7a5cf
- rebuild with openssl-1.0.1k
- release 3 (by relup.sh)

* Wed Oct 15 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 3d21fc5
- release 2 (by relup.sh)

* Sun Oct 05 2014 Jakub Bogusz <qboosh@pld-linux.org> b046379
- updated to 0.30.1

* Thu Aug 07 2014 Kacper Kornet <draenog@pld-linux.org> 659d948
- release 6 (rebuild with openssl-1.0.1i)

* Thu Jun 05 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> b6af6b4
- release 5 (by relup.sh)

